@@ -47,6 +47,7 @@ was written by Jeff Waugh and is available at www.perkypants.org
 
 from __future__ import print_function, unicode_literals
 
+import datetime
 import gzip
 import io
 import itertools
@@ -56,15 +57,17 @@ import re
 import shlex
 import shutil
 import sys
-import datetime
+
 
 try:
     from urllib import quote
 except ImportError:
     from urllib.parse import quote
 
-from ._version import (
-    __version__ as VERSION, __date__ as RELEASE, __homepage__ as HOMEPAGE)
+from ._version import __date__ as RELEASE
+from ._version import __homepage__ as HOMEPAGE
+from ._version import __version__ as VERSION
+
 
 try:
     unicode
@@ -185,7 +188,6 @@ class LogParser(object):
                 if m:
                     oldnick = m.group(1)
                     newnick = m.group(2)
-                    line = line
                     yield time, self.NICKCHANGE, (line, oldnick, newnick)
                 elif self.SERVMSG_REGEXP.match(line):
                     yield time, self.SERVER, line
@@ -462,7 +464,7 @@ class SimpleTextStyle(AbstractStyle):
         print("""
 <br>Generated by irclog2html.py %(VERSION)s by <a href="mailto:marius@pov.lt">Marius Gedminas</a>
  - find it at <a href="%(HOMEPAGE)s">%(HOMEPAGE)s</a>!
- </tt></body></html>""" % {'VERSION': VERSION, 'RELEASE': RELEASE,
+ </tt></body></html>""" % {'VERSION': VERSION,
                            'HOMEPAGE': escape(HOMEPAGE)},
               end=' ', file=self.outfile)
 
@@ -625,7 +627,7 @@ class XHTMLStyle(AbstractStyle):
  - find it at <a href="%(HOMEPAGE)s">%(HOMEPAGE)s</a>!</p>
 </div>
 </body>
-</html>""" % {'VERSION': VERSION, 'RELEASE': RELEASE,
+</html>""" % {'VERSION': VERSION,
               'HOMEPAGE': escape(HOMEPAGE)}, file=self.outfile)
 
     def servermsg(self, time, what, text):
@@ -845,10 +847,9 @@ def do_config_file(option, opt_str, value, parser):
 
 
 def parse_args(argv=sys.argv):
-    progname = os.path.basename(argv[0])
     parser = optparse.OptionParser("usage: %prog [options] filename [...]",
-                                   prog=progname,
                                    version=VERSION,
+                                   prog='irclog2html',
                                    description="Colourises and converts IRC"
                                                " logs to HTML format for easy"
                                                " web reading.")
